@@ -98,17 +98,17 @@ def callback_func(interface, method, arguments, user_data):
         #column[2] : optional protocol type
         rdr_xref = csv.reader(open("/usr/lib/dbus-switchboard/dbus-switch-xref.cfg", "rb"))
         for rowxref in rdr_xref:
-
             #Add protocol checks (if specified) for this xref
             #Useful for links like tel: or ssh: links which may not have an extension to associate against
             ProtocolDetect = "no"
             # print "("+rowxref[0].upper()+") ("+realparams[-6:-2]+")"
-            if rowxref[2] != "" and realparams.startswith(rowxref[2]):
+            # print "("+rowxref[0]+")("+rowxref[1]+")("+rowxref[2]+")"
+            if rowxref[2] != "" and params2.startswith(rowxref[2]):
                 print "protocol!"
                 ProtocolDetect = "yes"
 
             # Modified comparison of file extension to be case insensitive
-            if (rowxref[0] != "" and realparams.upper().endswith(rowxref[0].upper())) or ProtocolDetect == "yes":
+            if (rowxref[0] != "" and params2.upper().endswith(rowxref[0].upper())) or ProtocolDetect == "yes":
                 rdr_apps = csv.reader(open("/usr/lib/dbus-switchboard/dbus-switch-apps.cfg", "rb"))
 
                 #Check APPS 
@@ -133,7 +133,7 @@ def callback_func(interface, method, arguments, user_data):
                         return
 
     if foundhandler == "no":
-        print "no handler found"
+        print "no extension / protocol handler found"
 
         print "**Load Mime XRef**"
         MIMEXREFPATH = '/home/user/.mimetypes/user-mimetypes.list'
