@@ -3,13 +3,25 @@
 # qole says: This hackish script really needs to go away. 
 #            It is embarrassing.
 
+if [ -e /etc/gnome/defaults.list ] ; then
+  MESSEDUP=`grep "Catch-all" /etc/gnome/defaults.list`
+  if [ "x" != "x$MESSEDUP" ] ; then
+     echo "Replacing defaults list with a clean copy."
+     cp /usr/lib/dbus-switchboard/pristine-defaults.list /etc/gnome/defaults.list
+  fi
+  echo "Breaking link to gnome defaults.list."
+  cp /etc/gnome/defaults.list /usr/share/applications/defaults.list
+fi
+
 cp /usr/share/applications/defaults.list /usr/share/applications/defaults.list~
 
+echo "Adding new lines to defaults.list and uri-action.defaults.list"
+
 echo "video/quicktime=hildon-mediaplayer.desktop" >> /usr/share/applications/defaults.list
 echo "video-quicktime=hildon-mediaplayer.desktop:X-Osso-URI-Action-Open" >> /usr/share/applications/uri-action-defaults.list
 
-echo "application/postscript=dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
-echo "application-postscript=dbus-switchboard.desktop" >> /usr/share/applications/uri-action-defaults.list
+echo "application/postscript=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
+echo "application-postscript=hildon-dbus-switchboard.desktop" >> /usr/share/applications/uri-action-defaults.list
 
 
 echo "" >> /usr/share/applications/defaults.list
