@@ -124,7 +124,7 @@ class dbus_switchboard_gui (hildon.Program):
         self.label_mode.set_text(self.mode.upper())
     def on_quit(self, widget, data=None):
         if not self.saved:
-            confirm = hildon.Note("confirmation", (self.window, "Do you want to save the settings?", gtk.STOCK_DIALOG_WARNING))
+            confirm = hildon.Note("confirmation", self.window, "Do you want to save the settings?", gtk.STOCK_DIALOG_WARNING)
             confirm.set_button_texts("Yes", "No")
             print "**confirm save**"
             response = confirm.run()
@@ -254,7 +254,7 @@ class dbus_switchboard_gui (hildon.Program):
                 print extension_entry.get_text()
 #                print self.xrefs
                 if extension_entry.get_text() in self.xrefs:
-                    confirm = hildon.Note("confirmation", (self.window, "Do you want to overwrite existing xref?", gtk.STOCK_DIALOG_WARNING))
+                    confirm = hildon.Note("confirmation", self.window, "Do you want to overwrite existing xref?", gtk.STOCK_DIALOG_WARNING)
                     confirm.set_button_texts("Yes", "No")
                     print "**confirm overwrite**"
                     response = confirm.run()
@@ -346,7 +346,7 @@ class dbus_switchboard_gui (hildon.Program):
             if name == None:
                 print "**new handler**"
                 if name_entry.get_text() in self.handlers:
-                    confirm = hildon.Note("confirmation", (self.window, "Do you want to overwrite existing handler?", gtk.STOCK_DIALOG_WARNING))
+                    confirm = hildon.Note("confirmation", self.window, "Do you want to overwrite existing handler?", gtk.STOCK_DIALOG_WARNING)
                     confirm.set_button_texts("Yes", "No")
                     print "**confirm overwrite**"
                     response = confirm.run()
@@ -611,7 +611,7 @@ class dbus_switchboard_gui (hildon.Program):
         data = self.mode_functions[self.mode][1].get_selection().get_selected()
         if type(data[1]) is gtk.TreeIter:
             name = data[0].get_value(data[1], 0)
-            confirm = hildon.Note("confirmation", (self.window, "Are you sure you want to delete " + name + "?", gtk.STOCK_DIALOG_WARNING))
+            confirm = hildon.Note("confirmation", self.window, "Are you sure you want to delete " + name + "?", gtk.STOCK_DIALOG_WARNING)
             confirm.set_button_texts("Yes", "No")
             print "**delete**"
             response = confirm.run()
